Module structs

Module structs 

Enums

StructError
Errors produced while handling struct-backed endpoints.

Traits

RepeStruct
Trait implemented by structs that can be exposed directly through the REPE router.

Functions

join_path
Build a fully-qualified child path from the current path segments.
path_from_segments
Build a path string from segments for error messages.
prepend_path
Prefix error paths with an additional segment when bubbling errors from nested structs.

Type Aliases

StructResult
Convenience alias for results returned by struct handlers.