pub struct AsyncClient { /* private fields */ }Implementations
Sourceimpl AsyncClient
impl AsyncClient
pub async fn connect<A: ToSocketAddrs>(addr: A) -> Result<Self>
pub async fn call_json<P: AsRef<str>, T: Serialize>( &self, path: P, body: &T, ) -> Result<Value, RepeError>
Sourcepub async fn call_json_with_timeout<P: AsRef<str>, T: Serialize>(
&self,
path: P,
body: &T,
timeout_duration: Duration,
) -> Result<Value, RepeError>
pub async fn call_json_with_timeout<P: AsRef<str>, T: Serialize>( &self, path: P, body: &T, timeout_duration: Duration, ) -> Result<Value, RepeError>
Send a JSON request and fail if no response arrives before timeout_duration.
pub async fn call_typed_json<P: AsRef<str>, T: Serialize, R: DeserializeOwned>( &self, path: P, body: &T, ) -> Result<R, RepeError>
Sourcepub async fn call_typed_json_with_timeout<P: AsRef<str>, T: Serialize, R: DeserializeOwned>(
&self,
path: P,
body: &T,
timeout_duration: Duration,
) -> Result<R, RepeError>
pub async fn call_typed_json_with_timeout<P: AsRef<str>, T: Serialize, R: DeserializeOwned>( &self, path: P, body: &T, timeout_duration: Duration, ) -> Result<R, RepeError>
Send a typed JSON request and fail if no response arrives before timeout_duration.
pub async fn call_typed_beve<P: AsRef<str>, T: Serialize, R: DeserializeOwned>( &self, path: P, body: &T, ) -> Result<R, RepeError>
Sourcepub async fn call_typed_beve_with_timeout<P: AsRef<str>, T: Serialize, R: DeserializeOwned>(
&self,
path: P,
body: &T,
timeout_duration: Duration,
) -> Result<R, RepeError>
pub async fn call_typed_beve_with_timeout<P: AsRef<str>, T: Serialize, R: DeserializeOwned>( &self, path: P, body: &T, timeout_duration: Duration, ) -> Result<R, RepeError>
Send a typed BEVE request and fail if no response arrives before timeout_duration.
pub async fn notify_json<P: AsRef<str>, T: Serialize>( &self, path: P, body: &T, ) -> Result<(), RepeError>
pub async fn notify_typed_json<P: AsRef<str>, T: Serialize>( &self, path: P, body: &T, ) -> Result<(), RepeError>
pub async fn notify_typed_beve<P: AsRef<str>, T: Serialize>( &self, path: P, body: &T, ) -> Result<(), RepeError>