Skip to main contentModule structs
Source - StructError
- Errors produced while handling struct-backed endpoints.
- RepeStruct
- Trait implemented by structs that can be exposed directly through the REPE router.
- join_path
- Build a fully-qualified child path from the current path segments.
- path_from_segments
- Build a path string from segments for error messages.
- prepend_path
- Prefix error paths with an additional segment when bubbling errors from nested structs.
- StructResult
- Convenience alias for results returned by struct handlers.